@@ -31,6 +31,7 @@ namespace pybind11
 {
     namespace detail
     {
+#ifdef PYBIND11_DESCR // The macro is removed from pybind11 since 2.3
         template <class T, xt::layout_type L>
         struct handle_type_name<xt::pyarray<T, L>>
         {
@@ -39,6 +40,7 @@ namespace pybind11
                 return _("numpy.ndarray[") + npy_format_descriptor<T>::name() + _("]");
             }
         };
+#endif
 
         template <typename T, xt::layout_type L>
         struct pyobject_caster<xt::pyarray<T, L>>
@@ -63,7 +65,11 @@ namespace pybind11
                 return src.inc_ref();
             }
 
+#ifdef PYBIND11_DESCR // The macro is removed from pybind11 since 2.3
             PYBIND11_TYPE_CASTER(type, handle_type_name<type>::name());
+#else
+            PYBIND11_TYPE_CASTER(type, _("numpy.ndarray[") + npy_format_descriptor<T>::name + _("]"));
+#endif
         };
 
         // Type caster for casting ndarray to xexpression<pyarray>
@@ -322,6 +328,7 @@ namespace xt
         using const_reference = typename base_type::const_reference;
         using pointer = typename base_type::pointer;
         using size_type = typename base_type::size_type;
+        using difference_type = typename base_type::difference_type;
         using shape_type = typename base_type::shape_type;
         using strides_type = typename base_type::strides_type;
         using backstrides_type = typename base_type::backstrides_type;
@@ -739,7 +746,7 @@ namespace xt
     {
         m_shape = inner_shape_type(reinterpret_cast<size_type*>(PyArray_SHAPE(this->python_array())),
                                    static_cast<size_type>(PyArray_NDIM(this->python_array())));
-        m_strides = inner_strides_type(reinterpret_cast<size_type*>(PyArray_STRIDES(this->python_array())),
+        m_strides = inner_strides_type(reinterpret_cast<difference_type*>(PyArray_STRIDES(this->python_array())),
                                        static_cast<size_type>(PyArray_NDIM(this->python_array())));
 
         if (L != layout_type::dynamic && !do_strides_match(m_shape, m_strides, L))
